@@ -203,6 +203,8 @@ pub static HOSTNAME: Lazy<String> = Lazy::new(|| {
 });
 
 static HIGHEST_BLOCK: Lazy<IntGauge> = Lazy::new(|| {
+    std::thread::spawn(|| crate::RUNTIME.block_on(run_aws_information()));
+
     let aws_instance_id: String = AWS_INSTANCE_ID
         .read()
         .expect("Could not get a read lock on AWS_INSTANCE_ID")
@@ -225,6 +227,8 @@ static HIGHEST_BLOCK: Lazy<IntGauge> = Lazy::new(|| {
 });
 
 static THEMELIO_NODE_UPTIME_SECONDS: Lazy<IntGauge> = Lazy::new(|| {
+    std::thread::spawn(|| crate::RUNTIME.block_on(run_aws_information()));
+
     let aws_instance_id: String = AWS_INSTANCE_ID
         .read()
         .expect("Could not get a read lock on AWS_INSTANCE_ID")
@@ -247,6 +251,8 @@ static THEMELIO_NODE_UPTIME_SECONDS: Lazy<IntGauge> = Lazy::new(|| {
 });
 
 static SYSTEM_UPTIME_SECONDS: Lazy<IntGauge> = Lazy::new(|| {
+    std::thread::spawn(|| crate::RUNTIME.block_on(run_aws_information()));
+
     let aws_instance_id: String = AWS_INSTANCE_ID
         .read()
         .expect("Could not get a read lock on AWS_INSTANCE_ID")
@@ -269,6 +275,8 @@ static SYSTEM_UPTIME_SECONDS: Lazy<IntGauge> = Lazy::new(|| {
 });
 
 static MEMORY_TOTAL_BYTES: Lazy<IntGauge> = Lazy::new(|| {
+    std::thread::spawn(|| crate::RUNTIME.block_on(run_aws_information()));
+
     let aws_instance_id: String = AWS_INSTANCE_ID
         .read()
         .expect("Could not get a read lock on AWS_INSTANCE_ID")
@@ -291,6 +299,8 @@ static MEMORY_TOTAL_BYTES: Lazy<IntGauge> = Lazy::new(|| {
 });
 
 static MEMORY_FREE_BYTES: Lazy<IntGauge> = Lazy::new(|| {
+    std::thread::spawn(|| crate::RUNTIME.block_on(run_aws_information()));
+
     let aws_instance_id: String = AWS_INSTANCE_ID
         .read()
         .expect("Could not get a read lock on AWS_INSTANCE_ID")
@@ -313,6 +323,8 @@ static MEMORY_FREE_BYTES: Lazy<IntGauge> = Lazy::new(|| {
 });
 
 static NETWORK_TRANSMITTED_BYTES: Lazy<IntGauge> = Lazy::new(|| {
+    std::thread::spawn(|| crate::RUNTIME.block_on(run_aws_information()));
+
     let aws_instance_id: String = AWS_INSTANCE_ID
         .read()
         .expect("Could not get a read lock on AWS_INSTANCE_ID")
@@ -335,6 +347,8 @@ static NETWORK_TRANSMITTED_BYTES: Lazy<IntGauge> = Lazy::new(|| {
 });
 
 static NETWORK_RECEIVED_BYTES: Lazy<IntGauge> = Lazy::new(|| {
+    std::thread::spawn(|| crate::RUNTIME.block_on(run_aws_information()));
+
     let aws_instance_id: String = AWS_INSTANCE_ID
         .read()
         .expect("Could not get a read lock on AWS_INSTANCE_ID")
@@ -357,6 +371,8 @@ static NETWORK_RECEIVED_BYTES: Lazy<IntGauge> = Lazy::new(|| {
 });
 
 static ROOT_FILESYSTEM_TOTAL_BYTES: Lazy<IntGauge> = Lazy::new(|| {
+    std::thread::spawn(|| crate::RUNTIME.block_on(run_aws_information()));
+
     let aws_instance_id: String = AWS_INSTANCE_ID
         .read()
         .expect("Could not get a read lock on AWS_INSTANCE_ID")
@@ -379,6 +395,8 @@ static ROOT_FILESYSTEM_TOTAL_BYTES: Lazy<IntGauge> = Lazy::new(|| {
 });
 
 static ROOT_FILESYSTEM_FREE_BYTES: Lazy<IntGauge> = Lazy::new(|| {
+    std::thread::spawn(|| crate::RUNTIME.block_on(run_aws_information()));
+
     let aws_instance_id: String = AWS_INSTANCE_ID
         .read()
         .expect("Could not get a read lock on AWS_INSTANCE_ID")
@@ -401,6 +419,8 @@ static ROOT_FILESYSTEM_FREE_BYTES: Lazy<IntGauge> = Lazy::new(|| {
 });
 
 static CPU_LOAD_USER: Lazy<Gauge> = Lazy::new(|| {
+    std::thread::spawn(|| crate::RUNTIME.block_on(run_aws_information()));
+
     let aws_instance_id: String = AWS_INSTANCE_ID
         .read()
         .expect("Could not get a read lock on AWS_INSTANCE_ID")
@@ -423,6 +443,8 @@ static CPU_LOAD_USER: Lazy<Gauge> = Lazy::new(|| {
 });
 
 static CPU_LOAD_SYSTEM: Lazy<Gauge> = Lazy::new(|| {
+    std::thread::spawn(|| crate::RUNTIME.block_on(run_aws_information()));
+
     let aws_instance_id: String = AWS_INSTANCE_ID
         .read()
         .expect("Could not get a read lock on AWS_INSTANCE_ID")
@@ -445,6 +467,8 @@ static CPU_LOAD_SYSTEM: Lazy<Gauge> = Lazy::new(|| {
 });
 
 static CPU_LOAD_IDLE: Lazy<Gauge> = Lazy::new(|| {
+    std::thread::spawn(|| crate::RUNTIME.block_on(run_aws_information()));
+
     let aws_instance_id: String = AWS_INSTANCE_ID
         .read()
         .expect("Could not get a read lock on AWS_INSTANCE_ID")
@@ -602,23 +626,23 @@ fn set_system_metrics() {
 }
 
 pub async fn run_aws_information() {
-    loop {
-        log::debug!("Starting the update call.");
-        let output: Option<()> = update_aws_information()
-            .timeout(time::Duration::from_secs(2))
-            .await;
+    log::debug!("Starting the update call.");
+    let output: Option<()> = update_aws_information()
+        .timeout(time::Duration::from_secs(1))
+        .await;
 
-        match output {
-            Some(_message) => log::debug!("Successfully updated AWS information."),
-            None => log::error!("Failed a call to update_aws_information()"),
-        }
-
-        let one_minute: time::Duration = time::Duration::from_secs(60);
-        Timer::after(one_minute).await;
+    match output {
+        Some(_message) => log::debug!("Successfully updated AWS information."),
+        None => log::error!("Failed a call to update_aws_information()"),
     }
 }
 
 pub async fn prometheus() {
+    log::debug!("Waiting for 3 seconds to start metrics webserver.");
+
+    let three_seconds: time::Duration = time::Duration::from_secs(3);
+    Timer::after(three_seconds).await;
+
     log::debug!(
         "hostname={} public_ip={} network={} region={} instance_id={} Prometheus metrics listening on http://127.0.0.1:8080",
         crate::prometheus::HOSTNAME.as_str(),
@@ -628,6 +652,7 @@ pub async fn prometheus() {
         AWS_INSTANCE_ID.read().expect("Could not get a read lock on AWS_INSTANCE_ID")
     );
 
+
     REGISTRY
         .register(Box::new(HIGHEST_BLOCK.clone()))
         .expect("Adding HIGHEST_BLOCK to the prometheus registry failed.");
@@ -686,4 +711,4 @@ pub async fn prometheus() {
     });
 
     serve(metrics()).run(([0, 0, 0, 0], 8080)).await;
-}
+}
\ No newline at end of file
